<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('finance.daily');

// 记录访问日志
record_log('访问日销售统计页面');

// 添加/编辑日销售统计处理
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加日销售统计
    if ($_POST['action'] == 'add') {
        $store_id = isset($_POST['store_id']) ? intval($_POST['store_id']) : 0;
        $sale_date = isset($_POST['sale_date']) ? trim($_POST['sale_date']) : '';
        $total_amount = isset($_POST['total_amount']) ? floatval($_POST['total_amount']) : 0;
        $order_count = isset($_POST['order_count']) ? intval($_POST['order_count']) : 0;
        $customer_count = isset($_POST['customer_count']) ? intval($_POST['customer_count']) : 0;
        $average_amount = ($customer_count > 0) ? ($total_amount / $customer_count) : 0;
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if ($store_id <= 0 || empty($sale_date) || $total_amount <= 0) {
            $error = '请填写完整销售统计信息！';
        } else {
            try {
                // 检查该门店该日期是否已有记录
                $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM fin_daily WHERE store_id = ? AND sale_date = ?");
                $stmt->execute([$store_id, $sale_date]);
                $result = $stmt->fetch();

                if ($result['count'] > 0) {
                    $error = '该门店该日期已有销售统计记录！';
                } else {
                    // 添加日销售统计
                    $stmt = $pdo->prepare("INSERT INTO fin_daily (store_id, sale_date, total_amount, order_count, customer_count, average_amount, status) VALUES (?, ?, ?, ?, ?, ?, ?)");
                    $result = $stmt->execute([$store_id, $sale_date, $total_amount, $order_count, $customer_count, $average_amount, $status]);

                    if ($result) {
                        record_log("添加日销售统计：{$sale_date} - 门店ID:{$store_id}");
                        $success = '日销售统计添加成功！';
                        // 重定向到没有参数的页面
                        header('Location: daily.php?success=add');
                        exit;
                    } else {
                        $error = '日销售统计添加失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 编辑日销售统计
    elseif ($_POST['action'] == 'edit') {
        $daily_id = isset($_POST['daily_id']) ? intval($_POST['daily_id']) : 0;
        $store_id = isset($_POST['store_id']) ? intval($_POST['store_id']) : 0;
        $sale_date = isset($_POST['sale_date']) ? trim($_POST['sale_date']) : '';
        $total_amount = isset($_POST['total_amount']) ? floatval($_POST['total_amount']) : 0;
        $order_count = isset($_POST['order_count']) ? intval($_POST['order_count']) : 0;
        $customer_count = isset($_POST['customer_count']) ? intval($_POST['customer_count']) : 0;
        $average_amount = ($customer_count > 0) ? ($total_amount / $customer_count) : 0;
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if ($daily_id <= 0 || $store_id <= 0 || empty($sale_date) || $total_amount <= 0) {
            $error = '请填写完整销售统计信息！';
        } else {
            try {
                // 检查该门店该日期是否已有其他记录
                $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM fin_daily WHERE store_id = ? AND sale_date = ? AND id != ?");
                $stmt->execute([$store_id, $sale_date, $daily_id]);
                $result = $stmt->fetch();

                if ($result['count'] > 0) {
                    $error = '该门店该日期已有其他销售统计记录！';
                } else {
                    // 更新日销售统计信息
                    $stmt = $pdo->prepare("UPDATE fin_daily SET store_id = ?, sale_date = ?, total_amount = ?, order_count = ?, customer_count = ?, average_amount = ?, status = ? WHERE id = ?");
                    $result = $stmt->execute([$store_id, $sale_date, $total_amount, $order_count, $customer_count, $average_amount, $status, $daily_id]);

                    if ($result) {
                        record_log("编辑日销售统计：{$sale_date} - 门店ID:{$store_id}");
                        $success = '日销售统计更新成功！';
                        // 重定向到没有参数的页面
                        header('Location: daily.php?success=edit');
                        exit;
                    } else {
                        $error = '日销售统计更新失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除日销售统计
    elseif ($_POST['action'] == 'delete') {
        $daily_id = isset($_POST['daily_id']) ? intval($_POST['daily_id']) : 0;

        if ($daily_id <= 0) {
            $error = '无效的销售统计ID！';
        } else {
            try {
                // 获取销售统计信息，用于日志记录
                $stmt = $pdo->prepare("SELECT sale_date, store_id FROM fin_daily WHERE id = ?");
                $stmt->execute([$daily_id]);
                $daily = $stmt->fetch();

                if (!$daily) {
                    $error = '销售统计记录不存在！';
                } else {
                    // 删除销售统计
                    $stmt = $pdo->prepare("DELETE FROM fin_daily WHERE id = ?");
                    $result = $stmt->execute([$daily_id]);

                    if ($result) {
                        record_log("删除日销售统计：{$daily['sale_date']} - 门店ID:{$daily['store_id']}");
                        $success = '销售统计删除成功！';
                    } else {
                        $error = '销售统计删除失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 筛选条件处理
$filter_store_id = isset($_GET['store_id']) ? intval($_GET['store_id']) : 0;
$filter_start_date = isset($_GET['start_date']) ? trim($_GET['start_date']) : ''; // 改为空，默认显示全部
$filter_end_date = isset($_GET['end_date']) ? trim($_GET['end_date']) : ''; // 改为空，默认显示全部
$filter_status = isset($_GET['status']) ? intval($_GET['status']) : -1; // -1表示全部

// 获取所有门店信息，用于下拉选择
try {
    $stmt = $pdo->query("SELECT id, store_name FROM store_info ORDER BY id");
    $stores = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取门店信息失败：' . $e->getMessage();
    $stores = [];
}

// 构建查询条件
$where = [];
$params = [];

if ($filter_store_id > 0) {
    $where[] = "store_id = ?";
    $params[] = $filter_store_id;
}

if (!empty($filter_start_date)) {
    $where[] = "sale_date >= ?";
    $params[] = $filter_start_date;
}

if (!empty($filter_end_date)) {
    $where[] = "sale_date <= ?";
    $params[] = $filter_end_date;
}

if ($filter_status >= 0) {
    $where[] = "status = ?";
    $params[] = $filter_status;
}

// 获取日销售统计数据
try {
    $sql = "
        SELECT d.*, s.store_name 
        FROM fin_daily d
        LEFT JOIN store_info s ON d.store_id = s.id
    ";

    if (!empty($where)) {
        $sql .= " WHERE " . implode(' AND ', $where);
    }

    $sql .= " ORDER BY d.sale_date DESC, d.store_id";

    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $dailies = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取销售统计数据失败：' . $e->getMessage();
    $dailies = [];
}

// 计算总计
$total_sales = 0;
$total_orders = 0;
$total_customers = 0;
foreach ($dailies as $daily) {
    if ($daily['status'] == 1) { // 只计算正常状态的记录
        $total_sales += $daily['total_amount'];
        $total_orders += $daily['order_count'];
        $total_customers += $daily['customer_count'];
    }
}
$total_average = ($total_customers > 0) ? ($total_sales / $total_customers) : 0;

// 判断是否显示表单
$show_form = false;
$edit_daily = null;

// 编辑日销售统计时显示表单并获取信息
if (isset($_GET['action']) && $_GET['action'] == 'edit' && isset($_GET['id'])) {
    $show_form = true;
    $edit_id = intval($_GET['id']);
    try {
        $stmt = $pdo->prepare("SELECT * FROM fin_daily WHERE id = ?");
        $stmt->execute([$edit_id]);
        $edit_daily = $stmt->fetch();
        if (!$edit_daily) {
            $error = '销售统计记录不存在！';
            $show_form = false;
        }
    } catch (PDOException $e) {
        $error = '获取销售统计信息失败：' . $e->getMessage();
        $show_form = false;
    }
}

// 添加日销售统计时显示表单
if (isset($_GET['action']) && $_GET['action'] == 'add') {
    $show_form = true;
}

// 页面顶部处理成功消息
if (isset($_GET['success'])) {
    if ($_GET['success'] == 'add') {
        $success = '销售统计添加成功！';
    } elseif ($_GET['success'] == 'edit') {
        $success = '销售统计信息更新成功！';
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>日销售统计</h2>
            <div class="breadcrumb">
                <a href="index.php">财务管理</a> &gt; 日销售统计
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <a href="daily.php?action=add" class="btn btn-add">添加销售统计</a>
            </div>

            <!-- 添加/编辑销售统计表单 -->
            <?php if ($show_form): ?>
                <div class="form-container">
                    <h3><?php echo $edit_daily ? '编辑销售统计' : '添加销售统计'; ?></h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="<?php echo $edit_daily ? 'edit' : 'add'; ?>">
                        <?php if ($edit_daily): ?>
                            <input type="hidden" name="daily_id" value="<?php echo $edit_daily['id']; ?>">
                        <?php endif; ?>

                        <div class="form-group">
                            <label for="store_id">选择门店：</label>
                            <select id="store_id" name="store_id" required>
                                <option value="">请选择门店</option>
                                <?php foreach ($stores as $store): ?>
                                    <option value="<?php echo $store['id']; ?>" <?php echo ($edit_daily && $edit_daily['store_id'] == $store['id']) ? 'selected' : ''; ?>>
                                        <?php echo htmlspecialchars($store['store_name']); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="sale_date">销售日期：</label>
                            <input type="date" id="sale_date" name="sale_date" value="<?php echo $edit_daily ? htmlspecialchars($edit_daily['sale_date']) : date('Y-m-d'); ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="total_amount">销售总额：</label>
                            <input type="number" id="total_amount" name="total_amount" min="0" step="0.01" value="<?php echo $edit_daily ? htmlspecialchars($edit_daily['total_amount']) : '0.00'; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="order_count">订单数量：</label>
                            <input type="number" id="order_count" name="order_count" min="0" value="<?php echo $edit_daily ? htmlspecialchars($edit_daily['order_count']) : '0'; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="customer_count">客户数量：</label>
                            <input type="number" id="customer_count" name="customer_count" min="0" value="<?php echo $edit_daily ? htmlspecialchars($edit_daily['customer_count']) : '0'; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="status">状态：</label>
                            <select id="status" name="status">
                                <option value="1" <?php echo ($edit_daily && $edit_daily['status'] == 1) ? 'selected' : ''; ?>>正常</option>
                                <option value="0" <?php echo ($edit_daily && $edit_daily['status'] == 0) ? 'selected' : ''; ?>>作废</option>
                            </select>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">保存</button>
                            <a href="daily.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php else: ?>
                <!-- 筛选表单 -->
                <div class="filter-form">
                    <h3>筛选条件</h3>
                    <form method="get" action="">
                        <div class="filter-row">
                            <div class="filter-item">
                                <label for="store_id">门店：</label>
                                <select id="store_id" name="store_id">
                                    <option value="0">全部门店</option>
                                    <?php foreach ($stores as $store): ?>
                                        <option value="<?php echo $store['id']; ?>" <?php echo ($filter_store_id == $store['id']) ? 'selected' : ''; ?>>
                                            <?php echo htmlspecialchars($store['store_name']); ?>
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                            </div>

                            <div class="filter-item">
                                <label for="status">状态：</label>
                                <select id="status" name="status">
                                    <option value="-1">全部</option>
                                    <option value="1" <?php echo ($filter_status == 1) ? 'selected' : ''; ?>>正常</option>
                                    <option value="0" <?php echo ($filter_status == 0) ? 'selected' : ''; ?>>作废</option>
                                </select>
                            </div>
                        </div>

                        <div class="filter-row">
                            <div class="filter-item">
                                <label for="start_date">开始日期：</label>
                                <input type="date" id="start_date" name="start_date" value="<?php echo $filter_start_date; ?>">
                            </div>

                            <div class="filter-item">
                                <label for="end_date">结束日期：</label>
                                <input type="date" id="end_date" name="end_date" value="<?php echo $filter_end_date; ?>">
                            </div>

                            <div class="filter-buttons">
                                <button type="submit" class="btn btn-primary">筛选</button>
                                <a href="daily.php" class="btn btn-secondary">重置</a>
                            </div>
                        </div>
                    </form>
                </div>

                <!-- 统计摘要 -->
                <div class="info-box">
                    <h3>统计摘要（<?php echo empty($filter_start_date) && empty($filter_end_date) ? '全部数据' : $filter_start_date . ' 至 ' . $filter_end_date; ?>）</h3>
                    <ul>
                        <li>总销售额：￥<?php echo number_format($total_sales, 2); ?></li>
                        <li>总订单数：<?php echo $total_orders; ?></li>
                        <li>总客户数：<?php echo $total_customers; ?></li>
                        <li>平均客单价：￥<?php echo number_format($total_average, 2); ?></li>
                    </ul>
                </div>

                <!-- 销售统计列表 -->
                <div class="table-container">
                    <h3>销售统计列表</h3>
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>门店</th>
                                <th>销售日期</th>
                                <th>销售总额</th>
                                <th>订单数量</th>
                                <th>客户数量</th>
                                <th>客单价</th>
                                <th>状态</th>
                                <th>创建时间</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (empty($dailies)): ?>
                                <tr>
                                    <td colspan="10" class="text-center">暂无销售统计数据</td>
                                </tr>
                            <?php else: ?>
                                <?php foreach ($dailies as $daily): ?>
                                    <tr>
                                        <td><?php echo $daily['id']; ?></td>
                                        <td><?php echo htmlspecialchars($daily['store_name']); ?></td>
                                        <td><?php echo $daily['sale_date']; ?></td>
                                        <td>￥<?php echo number_format($daily['total_amount'], 2); ?></td>
                                        <td><?php echo $daily['order_count']; ?></td>
                                        <td><?php echo $daily['customer_count']; ?></td>
                                        <td>￥<?php echo number_format($daily['average_amount'], 2); ?></td>
                                        <td>
                                            <?php
                                            if ($daily['status'] == 1) echo '<span class="status-active">正常</span>';
                                            else echo '<span class="status-inactive">作废</span>';
                                            ?>
                                        </td>
                                        <td><?php echo date('Y-m-d H:i', strtotime($daily['create_time'])); ?></td>
                                        <td>
                                            <a href="daily.php?action=edit&id=<?php echo $daily['id']; ?>" class="btn btn-sm btn-edit">编辑</a>
                                            <form method="post" action="" class="inline-form">
                                                <input type="hidden" name="action" value="delete">
                                                <input type="hidden" name="daily_id" value="<?php echo $daily['id']; ?>">
                                                <button type="submit" class="btn btn-sm btn-danger" onclick="return confirm('确定要删除该销售统计记录吗？');">删除</button>
                                            </form>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            <?php endif; ?>
        </div>
    </div>
</body>

</html>