<?php
// index.php 主框架页面
session_start();
require_once 'database_config.php';

// 检查用户是否已登录，未登录则重定向到登录页面
if (!isset($_SESSION['user_id'])) {
    header('Location: login.php');
    exit;
}

?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <style>
        /* 基础样式 */
        * {
            margin: 0;
            padding: 0;
            box-sizing: border-box;
        }

        body {
            font-family: 'Microsoft YaHei', Tahoma, Geneva, Verdana, sans-serif;
            background: #f0f2f5;
        }

        /* 侧边栏容器 */
        .sidebar {
            position: fixed;
            left: 0;
            top: 0;
            width: 200px;
            height: 100vh;
            background: #2c3e50;
            padding: 20px 0;
            box-shadow: 2px 0 5px rgba(0, 0, 0, 0.1);
            z-index: 100;
            overflow-y: auto;
        }

        /* 侧边栏导航 */
        .nav-menu {
            list-style: none;
        }

        .nav-item {
            margin: 5px 15px;
        }

        .nav-link {
            display: block;
            padding: 10px 15px;
            color: #ffffff !important;
            text-decoration: none;
            border-radius: 4px;
            transition: all 0.3s;
            font-size: 14px;
        }

        .nav-link:hover {
            background: #34495e;
            color: #ecf0f1;
        }

        /* 返回按钮样式 */
        .back-btn {
            background: #3498db;
            margin-bottom: 20px;
        }

        .back-btn:hover {
            background: #2980b9;
        }

        /* 折叠菜单 */
        .submenu {
            list-style: none;
            margin-left: 15px;
            display: none;
        }

        .nav-item.active .submenu {
            display: block;
        }

        .nav-item.active>a {
            background: #4CAF50;
            color: white !important;
        }

        .submenu .nav-link {
            padding: 8px 15px;
            font-size: 13px;
        }

        /* 选中状态样式 */
        .nav-link.selected {
            background: #4CAF50;
            color: white !important;
        }

        .submenu .nav-link.selected {
            background: #388E3C;
            color: white !important;
        }

        /* 右侧内容区 */
        .content-frame {
            margin-left: 200px;
            height: 100vh;
        }

        iframe {
            width: 100%;
            height: 100%;
            border: none;
            background: #fff;
        }

        /* 用户信息 */
        .user-info {
            color: #fff;
            padding: 10px 20px;
            margin-bottom: 20px;
            border-bottom: 1px solid #34495e;
            font-size: 14px;
        }

        /* 系统标题样式 */
        .main-title {
            text-align: center;
            background-color: #4CAF50;
            padding: 10px 0;
            margin-bottom: 0;
            border-bottom: 1px solid #e0e0e0;
        }

        .main-title h1 {
            margin: 0;
            color: #ffffff;
            font-size: 24px;
            font-weight: normal;
        }

        /* 页脚样式 */
        .main-footer {
            text-align: center;
            background-color: #f5f5f5;
            color: #333;
            padding: 5px 0;
            position: fixed;
            bottom: 0;
            width: calc(100% - 200px);
            margin-left: 0;
            font-size: 10px;
            border-top: 1px solid #e0e0e0;
        }
    </style>
</head>

<body>
    <!-- 侧边栏 -->
    <nav class="sidebar">
        <div class="user-info">
            用户: <?php echo htmlspecialchars($_SESSION['username']); ?>
        </div>
        <ul class="nav-menu">
            <li class="nav-item">
                <a href="logout.php" class="nav-link back-btn">
                    退出登录
                </a>
            </li>
            <!-- 1. 系统管理 -->
            <?php if (has_permission('system')): ?>
                <li class="nav-item" data-module="system">
                    <a href="javascript:void(0)" class="nav-link" onclick="toggleSubmenu(this.parentNode); loadPage('system/index.php', 'system')">
                        系统管理
                    </a>
                    <ul class="submenu">
                        <li><a href="javascript:void(0)" class="nav-link" data-page="user" onclick="loadPage('system/user.php', 'system', 'user')">用户管理</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="role" onclick="loadPage('system/role.php', 'system', 'role')">权限与角色管理</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="log" onclick="loadPage('system/log.php', 'system', 'log')">日志审计</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="backup" onclick="loadPage('system/backup.php', 'system', 'backup')">数据备份</a></li>
                    </ul>
                </li>
            <?php endif; ?>
            <!-- 2. 产品管理 -->
            <?php if (has_permission('product')): ?>
                <li class="nav-item" data-module="product">
                    <a href="javascript:void(0)" class="nav-link" onclick="toggleSubmenu(this.parentNode); loadPage('product/index.php', 'product')">
                        产品管理
                    </a>
                    <ul class="submenu">
                        <li><a href="javascript:void(0)" class="nav-link" data-page="category" onclick="loadPage('product/category.php', 'product', 'category')">产品分类管理</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="catalog" onclick="loadPage('product/catalog.php', 'product', 'catalog')">产品目录管理</a></li>
                    </ul>
                </li>
            <?php endif; ?>
            <!-- 3. 门店管理 -->
            <?php if (has_permission('store')): ?>
                <li class="nav-item" data-module="store">
                    <a href="javascript:void(0)" class="nav-link" onclick="toggleSubmenu(this.parentNode); loadPage('store/index.php', 'store')">
                        门店管理
                    </a>
                    <ul class="submenu">
                        <li><a href="javascript:void(0)" class="nav-link" data-page="multi" onclick="loadPage('store/multi.php', 'store', 'multi')">多门店管理</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="info" onclick="loadPage('store/info.php', 'store', 'info')">门店信息管理</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="employee" onclick="loadPage('store/employee.php', 'store', 'employee')">员工管理</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="equipment" onclick="loadPage('store/equipment.php', 'store', 'equipment')">设备管理</a></li>
                    </ul>
                </li>
            <?php endif; ?>

            <!-- 4. 订单与销售管理 -->
            <?php if (has_permission('order')): ?>
                <li class="nav-item" data-module="order">
                    <a href="javascript:void(0)" class="nav-link" onclick="toggleSubmenu(this.parentNode); loadPage('order/index.php', 'order')">
                        订单与销售管理
                    </a>
                    <ul class="submenu">
                        <li><a href="javascript:void(0)" class="nav-link" data-page="pos" onclick="loadPage('order/pos.php', 'order', 'pos')">前台点单系统</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="category" onclick="loadPage('order/category.php', 'order', 'category')">订单自动分类</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="payment" onclick="loadPage('order/payment.php', 'order', 'payment')">支付管理</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="process" onclick="loadPage('order/process.php', 'order', 'process')">订单处理</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="delivery" onclick="loadPage('order/delivery.php', 'order', 'delivery')">外卖对接</a></li>
                    </ul>
                </li>
            <?php endif; ?>

            <!-- 5. 库存与供应链管理 -->
            <?php if (has_permission('inventory')): ?>
                <li class="nav-item" data-module="inventory">
                    <a href="javascript:void(0)" class="nav-link" onclick="toggleSubmenu(this.parentNode); loadPage('inventory/index.php', 'inventory')">
                        库存与供应链管理
                    </a>
                    <ul class="submenu">
                        <li><a href="javascript:void(0)" class="nav-link" data-page="stock" onclick="loadPage('inventory/stock.php', 'inventory', 'stock')">原料库存管理</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="supplier" onclick="loadPage('inventory/supplier.php', 'inventory', 'supplier')">供应商管理</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="purchase" onclick="loadPage('inventory/purchase.php', 'inventory', 'purchase')">采购与入库</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="tracking" onclick="loadPage('inventory/tracking.php', 'inventory', 'tracking')">库存消耗追踪</a></li>
                    </ul>
                </li>
            <?php endif; ?>

            <!-- 6. 会员与营销管理 -->
            <?php if (has_permission('member')): ?>
                <li class="nav-item" data-module="member">
                    <a href="javascript:void(0)" class="nav-link" onclick="toggleSubmenu(this.parentNode); loadPage('member/index.php', 'member')">
                        会员与营销管理
                    </a>
                    <ul class="submenu">
                        <li><a href="javascript:void(0)" class="nav-link" data-page="info" onclick="loadPage('member/info.php', 'member', 'info')">会员系统</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="points" onclick="loadPage('member/points.php', 'member', 'points')">积分与优惠券</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="card" onclick="loadPage('member/card.php', 'member', 'card')">充值与储值卡</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="marketing" onclick="loadPage('member/marketing.php', 'member', 'marketing')">营销活动</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="notify" onclick="loadPage('member/notify.php', 'member', 'notify')">短信/微信通知</a></li>
                    </ul>
                </li>
            <?php endif; ?>

            <!-- 7. 财务与结算管理 -->
            <?php if (has_permission('finance')): ?>
                <li class="nav-item" data-module="finance">
                    <a href="javascript:void(0)" class="nav-link" onclick="toggleSubmenu(this.parentNode); loadPage('finance/index.php', 'finance')">
                        财务与结算管理
                    </a>
                    <ul class="submenu">
                        <li><a href="javascript:void(0)" class="nav-link" data-page="daily" onclick="loadPage('finance/daily.php', 'finance', 'daily')">日销售报表</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="income" onclick="loadPage('finance/income.php', 'finance', 'income')">收入与支出管理</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="profit" onclick="loadPage('finance/profit.php', 'finance', 'profit')">利润分析</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="salary" onclick="loadPage('finance/salary.php', 'finance', 'salary')">工资管理</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="bill" onclick="loadPage('finance/bill.php', 'finance', 'bill')">电子账单</a></li>
                    </ul>
                </li>
            <?php endif; ?>

            <!-- 8. 数据分析与报表 -->
            <?php if (has_permission('statistics')): ?>
                <li class="nav-item" data-module="statistics">
                    <a href="javascript:void(0)" class="nav-link" onclick="toggleSubmenu(this.parentNode); loadPage('statistics/index.php', 'statistics')">
                        数据分析与报表
                    </a>
                    <ul class="submenu">
                        <li><a href="javascript:void(0)" class="nav-link" data-page="sales" onclick="loadPage('statistics/sales.php', 'statistics', 'sales')">销售数据分析</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="customer" onclick="loadPage('statistics/customer.php', 'statistics', 'customer')">顾客消费行为分析</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="inventory" onclick="loadPage('statistics/inventory.php', 'statistics', 'inventory')">库存周转分析</a></li>
                        <li><a href="javascript:void(0)" class="nav-link" data-page="kpi" onclick="loadPage('statistics/kpi.php', 'statistics', 'kpi')">运营KPI统计</a></li>
                    </ul>
                </li>
            <?php endif; ?>
        </ul>
    </nav>

    <!-- 右侧内容区 -->
    <div class="content-frame">
        <div class="main-title">
            <h1><?php echo title; ?></h1>
        </div>

        <?php if (isset($_GET['error']) && $_GET['error'] == 'no_permission'): ?>
            <div style="background-color: #f8d7da; color: #721c24; padding: 10px; margin: 10px; border-radius: 4px; text-align: center;">
                <p>您没有权限访问此页面，请联系管理员获取相应权限。</p>
            </div>
        <?php endif; ?>

        <iframe name="contentFrame" id="mainFrame" src="system/index.php"></iframe>
        <div class="main-footer">
            版权所有 &copy; <?php echo date('Y'); ?> <?php echo title; ?>
        </div>
    </div>

    <script>
        // 当前选中的模块和页面
        let currentModule = 'system';
        let currentPage = '';

        // 页面加载函数
        function loadPage(pageUrl, module, page = '') {
            document.getElementById('mainFrame').src = pageUrl;

            // 更新当前选中的模块和页面
            currentModule = module;
            currentPage = page;

            // 更新菜单选中状态
            updateMenuSelection();
        }

        // 更新菜单选中状态
        function updateMenuSelection() {
            // 清除所有选中状态
            const allLinks = document.querySelectorAll('.nav-link');
            allLinks.forEach(link => {
                link.classList.remove('selected');
            });

            // 设置当前模块的选中状态
            const moduleItem = document.querySelector(`.nav-item[data-module="${currentModule}"]`);
            if (moduleItem) {
                const moduleLink = moduleItem.querySelector(':scope > a');
                moduleLink.classList.add('selected');

                // 如果有子页面，设置子页面的选中状态
                if (currentPage) {
                    const pageLink = moduleItem.querySelector(`.submenu .nav-link[data-page="${currentPage}"]`);
                    if (pageLink) {
                        pageLink.classList.add('selected');
                    }
                }
            }
        }

        // 切换子菜单显示/隐藏
        function toggleSubmenu(item) {
            // 先关闭所有已打开的子菜单
            const allItems = document.querySelectorAll('.nav-item');
            allItems.forEach(el => {
                if (el !== item && el.classList.contains('active')) {
                    el.classList.remove('active');
                }
            });

            // 切换当前项的active状态
            item.classList.toggle('active');

            // 更新菜单选中状态
            updateMenuSelection();
        }

        // 初始化加载默认页
        window.onload = function() {
            loadPage('system/index.php', 'system');

            // 默认展开第一个可访问的菜单
            const menuItems = document.querySelectorAll('.nav-item[data-module]');
            if (menuItems.length > 0) {
                // 找到第一个可见的菜单项
                let firstVisibleItem = null;
                menuItems.forEach(item => {
                    if (item.offsetParent !== null && !firstVisibleItem) {
                        firstVisibleItem = item;
                    }
                });

                if (firstVisibleItem) {
                    firstVisibleItem.classList.add('active');
                }
            }
        }
    </script>

</body>

</html>