<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('inventory');

// 记录访问日志
record_log('访问库存与供应链管理页面');
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>库存与供应链管理</h2>
        </div>

        <div class="content">
            <div class="dashboard">
                <div class="dashboard-card">
                    <h3>原料库存</h3>
                    <div class="number"><?php
                                        $stmt = $pdo->query("SELECT COUNT(*) as count FROM inv_material");
                                        $result = $stmt->fetch();
                                        echo $result['count'];
                                        ?></div>
                    <div class="desc">库存预警：<?php
                                            $stmt = $pdo->query("SELECT COUNT(*) as count FROM inv_material WHERE stock <= min_stock");
                                            $result = $stmt->fetch();
                                            echo $result['count'];
                                            ?></div>
                </div>

                <div class="dashboard-card">
                    <h3>供应商</h3>
                    <div class="number"><?php
                                        $stmt = $pdo->query("SELECT COUNT(*) as count FROM sup_info");
                                        $result = $stmt->fetch();
                                        echo $result['count'];
                                        ?></div>
                    <div class="desc">活跃供应商：<?php
                                            $stmt = $pdo->query("SELECT COUNT(*) as count FROM sup_info WHERE status = 1");
                                            $result = $stmt->fetch();
                                            echo $result['count'];
                                            ?></div>
                </div>

                <div class="dashboard-card">
                    <h3>采购订单</h3>
                    <div class="number"><?php
                                        $stmt = $pdo->query("SELECT COUNT(*) as count FROM pur_order WHERE status IN (1, 2)");
                                        $result = $stmt->fetch();
                                        echo $result['count'];
                                        ?></div>
                    <div class="desc">待审核：<?php
                                            $stmt = $pdo->query("SELECT COUNT(*) as count FROM pur_order WHERE status = 1");
                                            $result = $stmt->fetch();
                                            echo $result['count'];
                                            ?></div>
                </div>

                <div class="dashboard-card">
                    <h3>库存消耗</h3>
                    <div class="number"><?php
                                        $stmt = $pdo->query("SELECT COUNT(*) as count FROM inv_record WHERE DATE(create_time) = CURDATE()");
                                        $result = $stmt->fetch();
                                        echo $result['count'];
                                        ?></div>
                    <div class="desc">今日入库：<?php
                                            $stmt = $pdo->query("SELECT COUNT(*) as count FROM inv_record WHERE DATE(create_time) = CURDATE() AND record_type = 1");
                                            $result = $stmt->fetch();
                                            echo $result['count'];
                                            ?></div>
                </div>
            </div>

            <h2>功能导航</h2>
            <div class="function-links">
                <a href="stock.php" class="function-link">
                    <h3>原料库存管理</h3>
                </a>
                <a href="supplier.php" class="function-link">
                    <h3>供应商管理</h3>
                </a>
                <a href="purchase.php" class="function-link">
                    <h3>采购与入库</h3>
                </a>
                <a href="tracking.php" class="function-link">
                    <h3>库存消耗追踪</h3>
                </a>
            </div>

            <h2>库存预警</h2>
            <div class="inventory-warning">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>原料名称</th>
                            <th>门店</th>
                            <th>类别</th>
                            <th>单位</th>
                            <th>当前库存</th>
                            <th>最低库存</th>
                            <th>状态</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php
                        $stmt = $pdo->query("SELECT m.*, s.store_name 
                                    FROM inv_material m
                                    JOIN store_info s ON m.store_id = s.id
                                    WHERE m.stock <= m.min_stock
                                    ORDER BY (m.stock/m.min_stock) ASC LIMIT 8");

                        while ($row = $stmt->fetch()) {
                            $stockStatus = '';
                            if ($row['stock'] == 0) {
                                $stockStatus = '<span style="color:red">缺货</span>';
                            } elseif ($row['stock'] < $row['min_stock'] * 0.5) {
                                $stockStatus = '<span style="color:orange">紧急</span>';
                            } else {
                                $stockStatus = '<span style="color:#F08C00">预警</span>';
                            }

                            echo "<tr>
                                <td>{$row['name']}</td>
                                <td>{$row['store_name']}</td>
                                <td>{$row['category']}</td>
                                <td>{$row['unit']}</td>
                                <td>{$row['stock']}</td>
                                <td>{$row['min_stock']}</td>
                                <td>{$stockStatus}</td>
                            </tr>";
                        }

                        if ($stmt->rowCount() == 0) {
                            echo "<tr><td colspan='7' style='text-align:center'>暂无库存预警</td></tr>";
                        }
                        ?>
                    </tbody>
                </table>
            </div>

            <h2>最近采购订单</h2>
            <div class="recent-purchases">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>采购单号</th>
                            <th>门店</th>
                            <th>供应商</th>
                            <th>原料</th>
                            <th>数量</th>
                            <th>金额</th>
                            <th>状态</th>
                            <th>创建时间</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php
                        $stmt = $pdo->query("SELECT p.*, s.store_name, sup.name as sup_name 
                                FROM pur_order p
                                JOIN store_info s ON p.store_id = s.id
                                JOIN sup_info sup ON p.supplier_id = sup.id
                                ORDER BY p.create_time DESC LIMIT 5");

                        $purchaseStatus = [
                            1 => '待审核',
                            2 => '已审核',
                            3 => '已入库',
                            4 => '已取消'
                        ];

                        while ($row = $stmt->fetch()) {
                            echo "<tr>
                                <td>{$row['order_no']}</td>
                                <td>{$row['store_name']}</td>
                                <td>{$row['sup_name']}</td>
                                <td>{$row['material_name']}</td>
                                <td>{$row['quantity']} {$row['unit']}</td>
                                <td>" . number_format($row['amount'], 2) . "</td>
                                <td>{$purchaseStatus[$row['status']]}</td>
                                <td>" . date('m-d H:i', strtotime($row['create_time'])) . "</td>
                            </tr>";
                        }

                        if ($stmt->rowCount() == 0) {
                            echo "<tr><td colspan='8' style='text-align:center'>暂无采购订单</td></tr>";
                        }
                        ?>
                    </tbody>
                </table>
            </div>

            <h2>最近库存变动</h2>
            <div class="inventory-records">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>门店</th>
                            <th>原料</th>
                            <th>类型</th>
                            <th>数量</th>
                            <th>操作人</th>
                            <th>批次号</th>
                            <th>有效期</th>
                            <th>时间</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php
                        $stmt = $pdo->query("SELECT r.*, s.store_name, m.name as material_name, m.unit 
                                FROM inv_record r
                                JOIN store_info s ON r.store_id = s.id
                                JOIN inv_material m ON r.material_id = m.id
                                ORDER BY r.create_time DESC LIMIT 5");

                        $recordTypes = [
                            1 => '入库',
                            2 => '订单消耗',
                            3 => '报废',
                            4 => '盘点调整'
                        ];

                        while ($row = $stmt->fetch()) {
                            // 数量显示逻辑：入库为正数，消耗和报废为负数，盘点看具体数值
                            $quantityDisplay = $row['quantity'];
                            if ($row['record_type'] == 2 || $row['record_type'] == 3) {
                                $quantityDisplay = -$row['quantity'];
                            }

                            $expiryDate = $row['expiry_date'] ? $row['expiry_date'] : '-';
                            $batchNo = $row['batch_no'] ? $row['batch_no'] : '-';

                            echo "<tr>
                                <td>{$row['store_name']}</td>
                                <td>{$row['material_name']}</td>
                                <td>{$recordTypes[$row['record_type']]}</td>
                                <td>{$quantityDisplay} {$row['unit']}</td>
                                <td>{$row['operator']}</td>
                                <td>{$batchNo}</td>
                                <td>{$expiryDate}</td>
                                <td>" . date('m-d H:i', strtotime($row['create_time'])) . "</td>
                            </tr>";
                        }

                        if ($stmt->rowCount() == 0) {
                            echo "<tr><td colspan='8' style='text-align:center'>暂无库存变动记录</td></tr>";
                        }
                        ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>