<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('statistics');

// 记录访问日志
record_log('访问数据分析与报表页面');
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>数据分析与报表</h2>
        </div>

        <div class="content">
            <div class="dashboard">
                <div class="dashboard-card">
                    <h3>本月销售</h3>
                    <div class="number"><?php
                                        $currentMonth = date('Y-m');
                                        $stmt = $pdo->prepare("SELECT SUM(sale_amount) as total FROM rpt_sales WHERE period = ?");
                                        $stmt->execute([$currentMonth]);
                                        $result = $stmt->fetch();
                                        echo number_format($result['total'] ?: 0, 2);
                                        ?></div>
                    <div class="desc">销量：<?php
                                            $stmt = $pdo->prepare("SELECT SUM(sale_count) as count FROM rpt_sales WHERE period = ?");
                                            $stmt->execute([$currentMonth]);
                                            $result = $stmt->fetch();
                                            echo $result['count'] ?: 0;
                                            ?> 单</div>
                </div>

                <div class="dashboard-card">
                    <h3>会员消费</h3>
                    <div class="number"><?php
                                        $stmt = $pdo->prepare("SELECT SUM(total_amount) as total FROM rpt_member WHERE period = ?");
                                        $stmt->execute([$currentMonth]);
                                        $result = $stmt->fetch();
                                        echo number_format($result['total'] ?: 0, 2);
                                        ?></div>
                    <div class="desc">客单价：<?php
                                            $stmt = $pdo->prepare("SELECT AVG(avg_amount) as avg FROM rpt_member WHERE period = ?");
                                            $stmt->execute([$currentMonth]);
                                            $result = $stmt->fetch();
                                            echo number_format($result['avg'] ?: 0, 2);
                                            ?></div>
                </div>

                <div class="dashboard-card">
                    <h3>库存周转</h3>
                    <div class="number"><?php
                                        $stmt = $pdo->prepare("SELECT AVG(turnover_days) as days FROM rpt_inventory WHERE period = ?");
                                        $stmt->execute([$currentMonth]);
                                        $result = $stmt->fetch();
                                        echo number_format($result['days'] ?: 0, 1);
                                        ?></div>
                    <div class="desc">平均周转天数</div>
                </div>

                <div class="dashboard-card">
                    <h3>业绩增长</h3>
                    <div class="number"><?php
                                        $stmt = $pdo->prepare("SELECT revenue_growth FROM rpt_kpi WHERE period = ?");
                                        $stmt->execute([$currentMonth]);
                                        $result = $stmt->fetch();
                                        echo $result['revenue_growth'] ? $result['revenue_growth'] . '%' : '0%';
                                        ?></div>
                    <div class="desc">环比上月</div>
                </div>
            </div>

            <h2>功能导航</h2>
            <div class="function-links">
                <a href="sales.php" class="function-link">
                    <h3>销售数据分析</h3>
                </a>
                <a href="customer.php" class="function-link">
                    <h3>顾客消费行为分析</h3>
                </a>
                <a href="inventory.php" class="function-link">
                    <h3>库存周转分析</h3>
                </a>
                <a href="kpi.php" class="function-link">
                    <h3>运营KPI统计</h3>
                </a>
            </div>

            <h2>本月畅销商品TOP5</h2>
            <div class="top-sales">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>排名</th>
                            <th>产品名称</th>
                            <th>类别</th>
                            <th>销售数量</th>
                            <th>销售金额</th>
                            <th>均价</th>
                            <th>门店</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php
                        $currentMonth = date('Y-m');
                        $stmt = $pdo->prepare("SELECT s.*, st.store_name 
                                FROM rpt_sales s
                                JOIN store_info st ON s.store_id = st.id
                                WHERE s.period = ?
                                ORDER BY s.sale_amount DESC LIMIT 5");
                        $stmt->execute([$currentMonth]);

                        $rank = 1;
                        while ($row = $stmt->fetch()) {
                            $avgPrice = $row['sale_count'] > 0 ? number_format($row['sale_amount'] / $row['sale_count'], 2) : 0;

                            echo "<tr>
                                <td>{$rank}</td>
                                <td>{$row['product_name']}</td>
                                <td>{$row['category']}</td>
                                <td>{$row['sale_count']}</td>
                                <td>" . number_format($row['sale_amount'], 2) . "</td>
                                <td>{$avgPrice}</td>
                                <td>{$row['store_name']}</td>
                            </tr>";
                            $rank++;
                        }

                        if ($stmt->rowCount() == 0) {
                            echo "<tr><td colspan='7' style='text-align:center'>暂无销售数据</td></tr>";
                        }
                        ?>
                    </tbody>
                </table>
            </div>

            <h2>会员消费TOP排行</h2>
            <div class="top-members">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>会员ID</th>
                            <th>门店</th>
                            <th>消费总额</th>
                            <th>到店次数</th>
                            <th>客单价</th>
                            <th>最常购买</th>
                            <th>偏好品类</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php
                        $stmt = $pdo->prepare("SELECT r.*, m.name as member_name, m.phone, st.store_name 
                                FROM rpt_member r
                                JOIN mem_info m ON r.member_id = m.id
                                JOIN store_info st ON r.store_id = st.id
                                WHERE r.period = ?
                                ORDER BY r.total_amount DESC LIMIT 5");
                        $stmt->execute([$currentMonth]);

                        while ($row = $stmt->fetch()) {
                            echo "<tr>
                                <td>{$row['member_name']} (ID:{$row['member_id']})</td>
                                <td>{$row['store_name']}</td>
                                <td>" . number_format($row['total_amount'], 2) . "</td>
                                <td>{$row['visit_count']}</td>
                                <td>" . number_format($row['avg_amount'], 2) . "</td>
                                <td>{$row['fav_product_name']}</td>
                                <td>{$row['fav_category']}</td>
                            </tr>";
                        }

                        if ($stmt->rowCount() == 0) {
                            echo "<tr><td colspan='7' style='text-align:center'>暂无会员消费数据</td></tr>";
                        }
                        ?>
                    </tbody>
                </table>
            </div>

            <h2>库存周转分析</h2>
            <div class="inventory-turnover">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>原料名称</th>
                            <th>门店</th>
                            <th>期初库存</th>
                            <th>期末库存</th>
                            <th>入库数量</th>
                            <th>消耗数量</th>
                            <th>周转天数</th>
                            <th>日均消耗率</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php
                        $stmt = $pdo->prepare("SELECT i.*, st.store_name 
                                FROM rpt_inventory i
                                JOIN store_info st ON i.store_id = st.id
                                WHERE i.period = ?
                                ORDER BY i.turnover_days ASC LIMIT 5");
                        $stmt->execute([$currentMonth]);

                        while ($row = $stmt->fetch()) {
                            $turnoverClass = '';
                            if ($row['turnover_days'] > 90) {
                                $turnoverClass = 'style="color:red"';
                            } elseif ($row['turnover_days'] < 15) {
                                $turnoverClass = 'style="color:green"';
                            }

                            echo "<tr>
                                <td>{$row['material_name']}</td>
                                <td>{$row['store_name']}</td>
                                <td>{$row['begin_stock']}</td>
                                <td>{$row['end_stock']}</td>
                                <td>{$row['in_qty']}</td>
                                <td>{$row['out_qty']}</td>
                                <td {$turnoverClass}>{$row['turnover_days']}</td>
                                <td>{$row['consumption_rate']}</td>
                            </tr>";
                        }

                        if ($stmt->rowCount() == 0) {
                            echo "<tr><td colspan='8' style='text-align:center'>暂无库存周转数据</td></tr>";
                        }
                        ?>
                    </tbody>
                </table>
            </div>

            <h2>运营KPI指标</h2>
            <div class="kpi-statistics">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>周期</th>
                            <th>门店</th>
                            <th>订单数</th>
                            <th>客流量</th>
                            <th>营业额</th>
                            <th>增长率</th>
                            <th>毛利率</th>
                            <th>新增会员</th>
                            <th>会员占比</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php
                        $stmt = $pdo->query("SELECT k.*, st.store_name 
                                FROM rpt_kpi k
                                JOIN store_info st ON k.store_id = st.id
                                ORDER BY k.period DESC LIMIT 3");

                        while ($row = $stmt->fetch()) {
                            $growthClass = $row['revenue_growth'] >= 0 ? 'style="color:green"' : 'style="color:red"';

                            echo "<tr>
                                <td>{$row['period']}</td>
                                <td>{$row['store_name']}</td>
                                <td>{$row['order_count']}</td>
                                <td>{$row['customer_count']}</td>
                                <td>" . number_format($row['revenue'], 2) . "</td>
                                <td {$growthClass}>{$row['revenue_growth']}%</td>
                                <td>{$row['gross_profit_rate']}%</td>
                                <td>{$row['new_member_count']}</td>
                                <td>{$row['member_ratio']}%</td>
                            </tr>";
                        }

                        if ($stmt->rowCount() == 0) {
                            echo "<tr><td colspan='9' style='text-align:center'>暂无KPI数据</td></tr>";
                        }
                        ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>