<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('store');

// 记录访问日志
record_log('访问员工管理页面');

// 获取所有门店列表（用于筛选）
try {
    $stmt = $pdo->query("SELECT id, store_name FROM store_info ORDER BY id");
    $stores = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取门店列表失败：' . $e->getMessage();
    $stores = [];
}

// 获取当前选择的门店ID
$store_id = isset($_GET['store_id']) ? intval($_GET['store_id']) : 0;

// 添加/编辑员工处理
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加员工
    if ($_POST['action'] == 'add') {
        $emp_store_id = isset($_POST['store_id']) ? intval($_POST['store_id']) : 0;
        $name = isset($_POST['name']) ? trim($_POST['name']) : '';
        $phone = isset($_POST['phone']) ? trim($_POST['phone']) : '';
        $position = isset($_POST['position']) ? trim($_POST['position']) : '';
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if ($emp_store_id <= 0 || empty($name)) {
            $error = '请填写完整员工信息！';
        } else {
            try {
                // 添加员工
                $stmt = $pdo->prepare("INSERT INTO emp_info (store_id, name, phone, position, status) VALUES (?, ?, ?, ?, ?)");
                $result = $stmt->execute([$emp_store_id, $name, $phone, $position, $status]);

                if ($result) {
                    record_log("添加员工：{$name}");
                    $success = '员工添加成功！';
                    // 重定向到没有参数的页面
                    header('Location: employee.php?success=add&store_id=' . $emp_store_id);
                    exit;
                } else {
                    $error = '员工添加失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 编辑员工
    elseif ($_POST['action'] == 'edit') {
        $emp_id = isset($_POST['emp_id']) ? intval($_POST['emp_id']) : 0;
        $emp_store_id = isset($_POST['store_id']) ? intval($_POST['store_id']) : 0;
        $name = isset($_POST['name']) ? trim($_POST['name']) : '';
        $phone = isset($_POST['phone']) ? trim($_POST['phone']) : '';
        $position = isset($_POST['position']) ? trim($_POST['position']) : '';
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if ($emp_id <= 0 || $emp_store_id <= 0 || empty($name)) {
            $error = '请填写完整员工信息！';
        } else {
            try {
                // 更新员工信息
                $stmt = $pdo->prepare("UPDATE emp_info SET store_id = ?, name = ?, phone = ?, position = ?, status = ? WHERE id = ?");
                $result = $stmt->execute([$emp_store_id, $name, $phone, $position, $status, $emp_id]);

                if ($result) {
                    record_log("编辑员工：{$name}");
                    $success = '员工信息更新成功！';
                    // 重定向到没有参数的页面
                    header('Location: employee.php?success=edit&store_id=' . $emp_store_id);
                    exit;
                } else {
                    $error = '员工信息更新失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除员工
    elseif ($_POST['action'] == 'delete') {
        $emp_id = isset($_POST['emp_id']) ? intval($_POST['emp_id']) : 0;

        if ($emp_id <= 0) {
            $error = '无效的员工ID！';
        } else {
            try {
                // 获取员工名称，用于日志记录
                $stmt = $pdo->prepare("SELECT name, store_id FROM emp_info WHERE id = ?");
                $stmt->execute([$emp_id]);
                $employee = $stmt->fetch();

                if (!$employee) {
                    $error = '员工不存在！';
                } else {
                    // 检查员工是否有关联工作记录
                    $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM emp_work WHERE emp_id = ?");
                    $stmt->execute([$emp_id]);
                    $work_records = $stmt->fetch();

                    if ($work_records['count'] > 0) {
                        $error = '该员工存在工作记录，无法删除！请先删除相关工作记录或将员工状态设置为离职。';
                    } else {
                        // 删除员工
                        $stmt = $pdo->prepare("DELETE FROM emp_info WHERE id = ?");
                        $result = $stmt->execute([$emp_id]);

                        if ($result) {
                            record_log("删除员工：{$employee['name']}");
                            $success = '员工删除成功！';
                            // 如果当前存在门店筛选，则保持筛选状态
                            if (isset($employee['store_id']) && $employee['store_id'] > 0) {
                                header('Location: employee.php?success=delete&store_id=' . $employee['store_id']);
                                exit;
                            }
                        } else {
                            $error = '员工删除失败！';
                        }
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 获取员工列表
try {
    $sql = "SELECT e.*, s.store_name 
            FROM emp_info e 
            JOIN store_info s ON e.store_id = s.id";

    $params = [];

    // 如果有门店筛选
    if ($store_id > 0) {
        $sql .= " WHERE e.store_id = ?";
        $params[] = $store_id;
    }

    $sql .= " ORDER BY e.id DESC";

    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $employees = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取员工列表失败：' . $e->getMessage();
    $employees = [];
}

// 判断是否显示表单
$show_form = false;
$edit_employee = null;

// 编辑员工时显示表单并获取员工信息
if (isset($_GET['action']) && $_GET['action'] == 'edit' && isset($_GET['id'])) {
    $show_form = true;
    $edit_id = intval($_GET['id']);
    try {
        $stmt = $pdo->prepare("SELECT * FROM emp_info WHERE id = ?");
        $stmt->execute([$edit_id]);
        $edit_employee = $stmt->fetch();
        if (!$edit_employee) {
            $error = '员工不存在！';
            $show_form = false;
        }
    } catch (PDOException $e) {
        $error = '获取员工信息失败：' . $e->getMessage();
        $show_form = false;
    }
}

// 添加员工时显示表单
if (isset($_GET['action']) && $_GET['action'] == 'add') {
    $show_form = true;
}

// 页面顶部处理成功消息
if (isset($_GET['success'])) {
    if ($_GET['success'] == 'add') {
        $success = '员工添加成功！';
    } elseif ($_GET['success'] == 'edit') {
        $success = '员工信息更新成功！';
    } elseif ($_GET['success'] == 'delete') {
        $success = '员工删除成功！';
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>员工管理</h2>
            <div class="breadcrumb">
                <a href="index.php">门店管理</a> &gt; 员工管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <!-- 门店筛选表单 -->
            <div class="filter-form">
                <form method="get" action="">
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="store_id">选择门店：</label>
                            <select id="store_id" name="store_id" onchange="this.form.submit()">
                                <option value="0">所有门店</option>
                                <?php foreach ($stores as $store): ?>
                                    <option value="<?php echo $store['id']; ?>" <?php echo ($store_id == $store['id']) ? 'selected' : ''; ?>>
                                        <?php echo htmlspecialchars($store['store_name']); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <div class="filter-item" style="flex: 0 0 auto; align-self: flex-end;">
                            <a href="employee.php?action=add<?php echo $store_id ? '&store_id=' . $store_id : ''; ?>" class="btn btn-add">添加员工</a>
                        </div>
                    </div>
                </form>
            </div>

            <!-- 添加/编辑员工表单 -->
            <?php if ($show_form): ?>
                <div class="form-container">
                    <h3><?php echo $edit_employee ? '编辑员工' : '添加员工'; ?></h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="<?php echo $edit_employee ? 'edit' : 'add'; ?>">
                        <?php if ($edit_employee): ?>
                            <input type="hidden" name="emp_id" value="<?php echo $edit_employee['id']; ?>">
                        <?php endif; ?>

                        <div class="form-group">
                            <label for="store_id">所属门店：</label>
                            <select id="store_id" name="store_id" required>
                                <option value="">-- 请选择门店 --</option>
                                <?php foreach ($stores as $store): ?>
                                    <option value="<?php echo $store['id']; ?>" <?php
                                                                                if ($edit_employee && $edit_employee['store_id'] == $store['id']) {
                                                                                    echo 'selected';
                                                                                } elseif (!$edit_employee && $store_id == $store['id']) {
                                                                                    echo 'selected';
                                                                                }
                                                                                ?>>
                                        <?php echo htmlspecialchars($store['store_name']); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="name">员工姓名：</label>
                            <input type="text" id="name" name="name" value="<?php echo $edit_employee ? htmlspecialchars($edit_employee['name']) : ''; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="phone">联系电话：</label>
                            <input type="text" id="phone" name="phone" value="<?php echo $edit_employee ? htmlspecialchars($edit_employee['phone']) : ''; ?>">
                        </div>

                        <div class="form-group">
                            <label for="position">职位：</label>
                            <select id="position" name="position">
                                <option value="店长" <?php echo ($edit_employee && $edit_employee['position'] == '店长') ? 'selected' : ''; ?>>店长</option>
                                <option value="副店长" <?php echo ($edit_employee && $edit_employee['position'] == '副店长') ? 'selected' : ''; ?>>副店长</option>
                                <option value="咖啡师" <?php echo ($edit_employee && $edit_employee['position'] == '咖啡师') ? 'selected' : ''; ?>>咖啡师</option>
                                <option value="店员" <?php echo ($edit_employee && $edit_employee['position'] == '店员') ? 'selected' : ''; ?>>店员</option>
                                <option value="收银员" <?php echo ($edit_employee && $edit_employee['position'] == '收银员') ? 'selected' : ''; ?>>收银员</option>
                                <option value="清洁员" <?php echo ($edit_employee && $edit_employee['position'] == '清洁员') ? 'selected' : ''; ?>>清洁员</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="status">状态：</label>
                            <select id="status" name="status">
                                <option value="1" <?php echo ($edit_employee && $edit_employee['status'] == 1) ? 'selected' : ''; ?>>在职</option>
                                <option value="0" <?php echo ($edit_employee && $edit_employee['status'] == 0) ? 'selected' : ''; ?>>离职</option>
                            </select>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">保存</button>
                            <a href="employee.php<?php echo $store_id ? '?store_id=' . $store_id : ''; ?>" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <!-- 员工列表 -->
            <div class="table-container">
                <h3>员工列表</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>姓名</th>
                            <th>所属门店</th>
                            <th>职位</th>
                            <th>联系电话</th>
                            <th>状态</th>
                            <th>入职时间</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($employees)): ?>
                            <tr>
                                <td colspan="8" class="text-center">暂无员工数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($employees as $employee): ?>
                                <tr>
                                    <td><?php echo $employee['id']; ?></td>
                                    <td><?php echo htmlspecialchars($employee['name']); ?></td>
                                    <td><?php echo htmlspecialchars($employee['store_name']); ?></td>
                                    <td><?php echo htmlspecialchars($employee['position'] ?: '-'); ?></td>
                                    <td><?php echo htmlspecialchars($employee['phone'] ?: '-'); ?></td>
                                    <td>
                                        <?php
                                        if ($employee['status'] == 1) echo '<span class="status-active">在职</span>';
                                        else echo '<span class="status-inactive">离职</span>';
                                        ?>
                                    </td>
                                    <td><?php echo $employee['create_time']; ?></td>
                                    <td>
                                        <a href="employee.php?action=edit&id=<?php echo $employee['id']; ?><?php echo $store_id ? '&store_id=' . $store_id : ''; ?>" class="btn btn-sm btn-edit">编辑</a>
                                        <form method="post" action="" class="inline-form">
                                            <input type="hidden" name="action" value="delete">
                                            <input type="hidden" name="emp_id" value="<?php echo $employee['id']; ?>">
                                            <button type="submit" class="btn btn-sm btn-danger" onclick="return confirm('确定要删除员工 \'<?php echo htmlspecialchars($employee['name']); ?>\' 吗？');">删除</button>
                                        </form>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>