<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('store');

// 记录访问日志
record_log('访问设备管理页面');

// 获取所有门店列表（用于筛选）
try {
    $stmt = $pdo->query("SELECT id, store_name FROM store_info ORDER BY id");
    $stores = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取门店列表失败：' . $e->getMessage();
    $stores = [];
}

// 获取当前选择的门店ID
$store_id = isset($_GET['store_id']) ? intval($_GET['store_id']) : 0;

// 添加/编辑设备处理
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加设备
    if ($_POST['action'] == 'add') {
        $equip_store_id = isset($_POST['store_id']) ? intval($_POST['store_id']) : 0;
        $name = isset($_POST['name']) ? trim($_POST['name']) : '';
        $type = isset($_POST['type']) ? trim($_POST['type']) : '';
        $purchase_date = isset($_POST['purchase_date']) ? trim($_POST['purchase_date']) : null;
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if ($equip_store_id <= 0 || empty($name) || empty($type)) {
            $error = '请填写完整设备信息！';
        } else {
            try {
                // 添加设备
                $stmt = $pdo->prepare("INSERT INTO equip_info (store_id, name, type, purchase_date, status) VALUES (?, ?, ?, ?, ?)");
                $result = $stmt->execute([$equip_store_id, $name, $type, $purchase_date, $status]);

                if ($result) {
                    record_log("添加设备：{$name}");
                    $success = '设备添加成功！';
                    // 重定向到没有参数的页面
                    header('Location: equipment.php?success=add&store_id=' . $equip_store_id);
                    exit;
                } else {
                    $error = '设备添加失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 编辑设备
    elseif ($_POST['action'] == 'edit') {
        $equip_id = isset($_POST['equip_id']) ? intval($_POST['equip_id']) : 0;
        $equip_store_id = isset($_POST['store_id']) ? intval($_POST['store_id']) : 0;
        $name = isset($_POST['name']) ? trim($_POST['name']) : '';
        $type = isset($_POST['type']) ? trim($_POST['type']) : '';
        $purchase_date = isset($_POST['purchase_date']) ? trim($_POST['purchase_date']) : null;
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if ($equip_id <= 0 || $equip_store_id <= 0 || empty($name) || empty($type)) {
            $error = '请填写完整设备信息！';
        } else {
            try {
                // 更新设备信息
                $stmt = $pdo->prepare("UPDATE equip_info SET store_id = ?, name = ?, type = ?, purchase_date = ?, status = ? WHERE id = ?");
                $result = $stmt->execute([$equip_store_id, $name, $type, $purchase_date, $status, $equip_id]);

                if ($result) {
                    record_log("编辑设备：{$name}");
                    $success = '设备信息更新成功！';
                    // 重定向到没有参数的页面
                    header('Location: equipment.php?success=edit&store_id=' . $equip_store_id);
                    exit;
                } else {
                    $error = '设备信息更新失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除设备
    elseif ($_POST['action'] == 'delete') {
        $equip_id = isset($_POST['equip_id']) ? intval($_POST['equip_id']) : 0;

        if ($equip_id <= 0) {
            $error = '无效的设备ID！';
        } else {
            try {
                // 获取设备名称，用于日志记录
                $stmt = $pdo->prepare("SELECT name, store_id FROM equip_info WHERE id = ?");
                $stmt->execute([$equip_id]);
                $equipment = $stmt->fetch();

                if (!$equipment) {
                    $error = '设备不存在！';
                } else {
                    // 检查设备是否有关联维护记录
                    $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM equip_maintain WHERE equip_id = ?");
                    $stmt->execute([$equip_id]);
                    $maintain_records = $stmt->fetch();

                    if ($maintain_records['count'] > 0) {
                        $error = '该设备存在维护记录，无法删除！请先删除相关维护记录。';
                    } else {
                        // 删除设备
                        $stmt = $pdo->prepare("DELETE FROM equip_info WHERE id = ?");
                        $result = $stmt->execute([$equip_id]);

                        if ($result) {
                            record_log("删除设备：{$equipment['name']}");
                            $success = '设备删除成功！';
                            // 如果当前存在门店筛选，则保持筛选状态
                            if (isset($equipment['store_id']) && $equipment['store_id'] > 0) {
                                header('Location: equipment.php?success=delete&store_id=' . $equipment['store_id']);
                                exit;
                            }
                        } else {
                            $error = '设备删除失败！';
                        }
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 添加维护记录
    elseif ($_POST['action'] == 'add_maintain') {
        $equip_id = isset($_POST['equip_id']) ? intval($_POST['equip_id']) : 0;
        $store_id = isset($_POST['store_id']) ? intval($_POST['store_id']) : 0;
        $maintain_date = isset($_POST['maintain_date']) ? trim($_POST['maintain_date']) : '';
        $maintain_type = isset($_POST['maintain_type']) ? intval($_POST['maintain_type']) : 1;
        $operator = isset($_POST['operator']) ? trim($_POST['operator']) : '';
        $description = isset($_POST['description']) ? trim($_POST['description']) : '';

        if ($equip_id <= 0 || $store_id <= 0 || empty($maintain_date) || empty($operator)) {
            $error = '请填写完整维护记录信息！';
        } else {
            try {
                // 添加维护记录
                $stmt = $pdo->prepare("INSERT INTO equip_maintain (equip_id, store_id, maintain_date, maintain_type, operator, description) VALUES (?, ?, ?, ?, ?, ?)");
                $result = $stmt->execute([$equip_id, $store_id, $maintain_date, $maintain_type, $operator, $description]);

                if ($result) {
                    record_log("添加设备维护记录，设备ID：{$equip_id}");
                    $success = '维护记录添加成功！';
                    // 重定向到没有参数的页面
                    header('Location: equipment.php?success=maintain_add&id=' . $equip_id . '&store_id=' . $store_id);
                    exit;
                } else {
                    $error = '维护记录添加失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 获取设备列表
try {
    $sql = "SELECT e.*, s.store_name 
            FROM equip_info e 
            JOIN store_info s ON e.store_id = s.id";

    $params = [];

    // 如果有门店筛选
    if ($store_id > 0) {
        $sql .= " WHERE e.store_id = ?";
        $params[] = $store_id;
    }

    $sql .= " ORDER BY e.id DESC";

    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $equipment = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取设备列表失败：' . $e->getMessage();
    $equipment = [];
}

// 先判断是否是编辑操作
$show_form = false;
$edit_equipment = null;

// 编辑设备时显示表单并获取设备信息
if (isset($_GET['action']) && $_GET['action'] == 'edit' && isset($_GET['id'])) {
    $show_form = true;
    $edit_id = intval($_GET['id']);
    try {
        $stmt = $pdo->prepare("SELECT * FROM equip_info WHERE id = ?");
        $stmt->execute([$edit_id]);
        $edit_equipment = $stmt->fetch();
        if (!$edit_equipment) {
            $error = '设备不存在！';
            $show_form = false;
        }
    } catch (PDOException $e) {
        $error = '获取设备信息失败：' . $e->getMessage();
        $show_form = false;
    }
}

// 添加设备时显示表单
if (isset($_GET['action']) && $_GET['action'] == 'add') {
    $show_form = true;
}

// 只有不是编辑或添加操作时，才获取设备详情
$maintain_records = [];
$current_equipment = null;
if (!$show_form && isset($_GET['id']) && intval($_GET['id']) > 0) {
    $equip_id = intval($_GET['id']);
    try {
        // 获取设备信息
        $stmt = $pdo->prepare("SELECT e.*, s.store_name 
                              FROM equip_info e 
                              JOIN store_info s ON e.store_id = s.id
                              WHERE e.id = ?");
        $stmt->execute([$equip_id]);
        $current_equipment = $stmt->fetch();

        if ($current_equipment) {
            // 获取维护记录
            $stmt = $pdo->prepare("SELECT * FROM equip_maintain WHERE equip_id = ? ORDER BY maintain_date DESC");
            $stmt->execute([$equip_id]);
            $maintain_records = $stmt->fetchAll();
        }
    } catch (PDOException $e) {
        $error = '获取维护记录失败：' . $e->getMessage();
    }
}

// 页面顶部处理成功消息
if (isset($_GET['success'])) {
    if ($_GET['success'] == 'add') {
        $success = '设备添加成功！';
    } elseif ($_GET['success'] == 'edit') {
        $success = '设备信息更新成功！';
    } elseif ($_GET['success'] == 'delete') {
        $success = '设备删除成功！';
    } elseif ($_GET['success'] == 'maintain_add') {
        $success = '维护记录添加成功！';
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>设备管理</h2>
            <div class="breadcrumb">
                <a href="index.php">门店管理</a> &gt; 设备管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <?php if ($show_form): ?>
                <!-- 添加/编辑设备表单 -->
                <div class="form-container">
                    <h3><?php echo $edit_equipment ? '编辑设备' : '添加设备'; ?></h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="<?php echo $edit_equipment ? 'edit' : 'add'; ?>">
                        <?php if ($edit_equipment): ?>
                            <input type="hidden" name="equip_id" value="<?php echo $edit_equipment['id']; ?>">
                        <?php endif; ?>

                        <div class="form-group">
                            <label for="store_id">所属门店：</label>
                            <select id="store_id" name="store_id" required>
                                <option value="">-- 请选择门店 --</option>
                                <?php foreach ($stores as $store): ?>
                                    <option value="<?php echo $store['id']; ?>" <?php
                                                                                if ($edit_equipment && $edit_equipment['store_id'] == $store['id']) {
                                                                                    echo 'selected';
                                                                                } elseif (!$edit_equipment && $store_id == $store['id']) {
                                                                                    echo 'selected';
                                                                                }
                                                                                ?>>
                                        <?php echo htmlspecialchars($store['store_name']); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="name">设备名称：</label>
                            <input type="text" id="name" name="name" value="<?php echo $edit_equipment ? htmlspecialchars($edit_equipment['name']) : ''; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="type">设备类型：</label>
                            <select id="type" name="type">
                                <option value="咖啡机" <?php echo ($edit_equipment && $edit_equipment['type'] == '咖啡机') ? 'selected' : ''; ?>>咖啡机</option>
                                <option value="收银机" <?php echo ($edit_equipment && $edit_equipment['type'] == '收银机') ? 'selected' : ''; ?>>收银机</option>
                                <option value="POS机" <?php echo ($edit_equipment && $edit_equipment['type'] == 'POS机') ? 'selected' : ''; ?>>POS机</option>
                                <option value="冷藏设备" <?php echo ($edit_equipment && $edit_equipment['type'] == '冷藏设备') ? 'selected' : ''; ?>>冷藏设备</option>
                                <option value="制冰机" <?php echo ($edit_equipment && $edit_equipment['type'] == '制冰机') ? 'selected' : ''; ?>>制冰机</option>
                                <option value="烘焙设备" <?php echo ($edit_equipment && $edit_equipment['type'] == '烘焙设备') ? 'selected' : ''; ?>>烘焙设备</option>
                                <option value="其他" <?php echo ($edit_equipment && $edit_equipment['type'] == '其他') ? 'selected' : ''; ?>>其他</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="purchase_date">购买日期：</label>
                            <input type="date" id="purchase_date" name="purchase_date" value="<?php echo $edit_equipment ? $edit_equipment['purchase_date'] : ''; ?>">
                        </div>

                        <div class="form-group">
                            <label for="status">状态：</label>
                            <select id="status" name="status">
                                <option value="1" <?php echo ($edit_equipment && $edit_equipment['status'] == 1) ? 'selected' : ''; ?>>正常</option>
                                <option value="2" <?php echo ($edit_equipment && $edit_equipment['status'] == 2) ? 'selected' : ''; ?>>维修中</option>
                                <option value="3" <?php echo ($edit_equipment && $edit_equipment['status'] == 3) ? 'selected' : ''; ?>>已报废</option>
                            </select>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">保存</button>
                            <a href="equipment.php<?php echo $store_id ? '?store_id=' . $store_id : ''; ?>" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php elseif ($current_equipment): ?>
                <!-- 设备详情和维护记录 -->
                <div class="form-container">
                    <h3>设备详情：<?php echo htmlspecialchars($current_equipment['name']); ?></h3>
                    <table class="info-table">
                        <tr>
                            <td>设备ID：</td>
                            <td><?php echo $current_equipment['id']; ?></td>
                        </tr>
                        <tr>
                            <td>设备名称：</td>
                            <td><?php echo htmlspecialchars($current_equipment['name']); ?></td>
                        </tr>
                        <tr>
                            <td>所属门店：</td>
                            <td><?php echo htmlspecialchars($current_equipment['store_name']); ?></td>
                        </tr>
                        <tr>
                            <td>设备类型：</td>
                            <td><?php echo htmlspecialchars($current_equipment['type']); ?></td>
                        </tr>
                        <tr>
                            <td>购买日期：</td>
                            <td><?php echo $current_equipment['purchase_date'] ?: '-'; ?></td>
                        </tr>
                        <tr>
                            <td>状态：</td>
                            <td>
                                <?php
                                if ($current_equipment['status'] == 1) echo '<span class="status-active">正常</span>';
                                elseif ($current_equipment['status'] == 2) echo '<span style="color: orange;">维修中</span>';
                                else echo '<span class="status-inactive">已报废</span>';
                                ?>
                            </td>
                        </tr>
                    </table>

                    <div class="form-actions">
                        <a href="equipment.php?action=edit&id=<?php echo $current_equipment['id']; ?>&store_id=<?php echo $current_equipment['store_id']; ?>" class="btn btn-edit">编辑设备</a>
                        <a href="equipment.php<?php echo $store_id ? '?store_id=' . $store_id : ''; ?>" class="btn btn-secondary">返回设备列表</a>
                    </div>
                </div>

                <!-- 添加维护记录表单 -->
                <div class="form-container">
                    <h3>添加维护记录</h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="add_maintain">
                        <input type="hidden" name="equip_id" value="<?php echo $current_equipment['id']; ?>">
                        <input type="hidden" name="store_id" value="<?php echo $current_equipment['store_id']; ?>">

                        <div class="form-group">
                            <label for="maintain_date">维护日期：</label>
                            <input type="date" id="maintain_date" name="maintain_date" value="<?php echo date('Y-m-d'); ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="maintain_type">维护类型：</label>
                            <select id="maintain_type" name="maintain_type">
                                <option value="1">已完成维护</option>
                                <option value="2">计划维护</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="operator">维护人员：</label>
                            <input type="text" id="operator" name="operator" required>
                        </div>

                        <div class="form-group">
                            <label for="description">维护描述：</label>
                            <input type="text" id="description" name="description">
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">添加记录</button>
                        </div>
                    </form>
                </div>

                <!-- 维护记录列表 -->
                <div class="table-container">
                    <h3>维护记录列表</h3>
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>维护日期</th>
                                <th>维护类型</th>
                                <th>维护人员</th>
                                <th>维护描述</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (empty($maintain_records)): ?>
                                <tr>
                                    <td colspan="5" class="text-center">暂无维护记录</td>
                                </tr>
                            <?php else: ?>
                                <?php foreach ($maintain_records as $record): ?>
                                    <tr>
                                        <td><?php echo $record['id']; ?></td>
                                        <td><?php echo $record['maintain_date']; ?></td>
                                        <td>
                                            <?php
                                            if ($record['maintain_type'] == 1) echo '已完成维护';
                                            else echo '<span style="color: orange;">计划维护</span>';
                                            ?>
                                        </td>
                                        <td><?php echo htmlspecialchars($record['operator']); ?></td>
                                        <td><?php echo htmlspecialchars($record['description'] ?: '-'); ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            <?php else: ?>
                <!-- 设备列表视图 -->
                <!-- 门店筛选表单 -->
                <div class="filter-form">
                    <form method="get" action="">
                        <div class="filter-row">
                            <div class="filter-item">
                                <label for="store_id">选择门店：</label>
                                <select id="store_id" name="store_id" onchange="this.form.submit()">
                                    <option value="0">所有门店</option>
                                    <?php foreach ($stores as $store): ?>
                                        <option value="<?php echo $store['id']; ?>" <?php echo ($store_id == $store['id']) ? 'selected' : ''; ?>>
                                            <?php echo htmlspecialchars($store['store_name']); ?>
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                            </div>
                            <div class="filter-item" style="flex: 0 0 auto; align-self: flex-end;">
                                <a href="equipment.php?action=add<?php echo $store_id ? '&store_id=' . $store_id : ''; ?>" class="btn btn-add">添加设备</a>
                            </div>
                        </div>
                    </form>
                </div>

                <!-- 设备列表 -->
                <div class="table-container">
                    <h3>设备列表</h3>
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>设备名称</th>
                                <th>所属门店</th>
                                <th>设备类型</th>
                                <th>购买日期</th>
                                <th>状态</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (empty($equipment)): ?>
                                <tr>
                                    <td colspan="7" class="text-center">暂无设备数据</td>
                                </tr>
                            <?php else: ?>
                                <?php foreach ($equipment as $equip): ?>
                                    <tr>
                                        <td><?php echo $equip['id']; ?></td>
                                        <td><?php echo htmlspecialchars($equip['name']); ?></td>
                                        <td><?php echo htmlspecialchars($equip['store_name']); ?></td>
                                        <td><?php echo htmlspecialchars($equip['type']); ?></td>
                                        <td><?php echo $equip['purchase_date'] ?: '-'; ?></td>
                                        <td>
                                            <?php
                                            if ($equip['status'] == 1) echo '<span class="status-active">正常</span>';
                                            elseif ($equip['status'] == 2) echo '<span style="color: orange;">维修中</span>';
                                            else echo '<span class="status-inactive">已报废</span>';
                                            ?>
                                        </td>
                                        <td>
                                            <a href="equipment.php?id=<?php echo $equip['id']; ?><?php echo $store_id ? '&store_id=' . $store_id : ''; ?>" class="btn btn-sm btn-details">维护记录</a>
                                            <a href="equipment.php?action=edit&id=<?php echo $equip['id']; ?><?php echo $store_id ? '&store_id=' . $store_id : ''; ?>" class="btn btn-sm btn-edit">编辑</a>
                                            <form method="post" action="" style="display: inline-block; margin: 0;">
                                                <input type="hidden" name="action" value="delete">
                                                <input type="hidden" name="equip_id" value="<?php echo $equip['id']; ?>">
                                                <button type="submit" class="btn btn-sm btn-danger" onclick="return confirm('确定要删除设备 \'<?php echo htmlspecialchars($equip['name']); ?>\' 吗？');">删除</button>
                                            </form>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            <?php endif; ?>
        </div>
    </div>
</body>

</html>