<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('store');

// 记录访问日志
record_log('访问多门店管理页面');

// 添加/编辑门店处理
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加门店
    if ($_POST['action'] == 'add') {
        $store_name = isset($_POST['store_name']) ? trim($_POST['store_name']) : '';
        $address = isset($_POST['address']) ? trim($_POST['address']) : '';
        $contact_phone = isset($_POST['contact_phone']) ? trim($_POST['contact_phone']) : '';
        $business_hours = isset($_POST['business_hours']) ? trim($_POST['business_hours']) : '';
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if (empty($store_name)) {
            $error = '请填写门店名称！';
        } else {
            try {
                // 检查门店名称是否已存在
                $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM store_info WHERE store_name = ?");
                $stmt->execute([$store_name]);
                $result = $stmt->fetch();

                if ($result['count'] > 0) {
                    $error = '门店名称已存在！';
                } else {
                    // 添加门店
                    $stmt = $pdo->prepare("INSERT INTO store_info (store_name, address, contact_phone, business_hours, status) VALUES (?, ?, ?, ?, ?)");
                    $result = $stmt->execute([$store_name, $address, $contact_phone, $business_hours, $status]);

                    if ($result) {
                        record_log("添加门店：{$store_name}");
                        $success = '门店添加成功！';
                        // 重定向到没有参数的页面
                        header('Location: multi.php?success=add');
                        exit;
                    } else {
                        $error = '门店添加失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 编辑门店
    elseif ($_POST['action'] == 'edit') {
        $store_id = isset($_POST['store_id']) ? intval($_POST['store_id']) : 0;
        $store_name = isset($_POST['store_name']) ? trim($_POST['store_name']) : '';
        $address = isset($_POST['address']) ? trim($_POST['address']) : '';
        $contact_phone = isset($_POST['contact_phone']) ? trim($_POST['contact_phone']) : '';
        $business_hours = isset($_POST['business_hours']) ? trim($_POST['business_hours']) : '';
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if ($store_id <= 0 || empty($store_name)) {
            $error = '请填写完整门店信息！';
        } else {
            try {
                // 检查门店名称是否已被其他门店使用
                $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM store_info WHERE store_name = ? AND id != ?");
                $stmt->execute([$store_name, $store_id]);
                $result = $stmt->fetch();

                if ($result['count'] > 0) {
                    $error = '门店名称已被其他门店使用！';
                } else {
                    // 更新门店信息
                    $stmt = $pdo->prepare("UPDATE store_info SET store_name = ?, address = ?, contact_phone = ?, business_hours = ?, status = ? WHERE id = ?");
                    $result = $stmt->execute([$store_name, $address, $contact_phone, $business_hours, $status, $store_id]);

                    if ($result) {
                        record_log("编辑门店：{$store_name}");
                        $success = '门店信息更新成功！';
                        // 重定向到没有参数的页面
                        header('Location: multi.php?success=edit');
                        exit;
                    } else {
                        $error = '门店信息更新失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除门店
    elseif ($_POST['action'] == 'delete') {
        $store_id = isset($_POST['store_id']) ? intval($_POST['store_id']) : 0;

        if ($store_id <= 0) {
            $error = '无效的门店ID！';
        } else {
            try {
                // 获取门店名称，用于日志记录
                $stmt = $pdo->prepare("SELECT store_name FROM store_info WHERE id = ?");
                $stmt->execute([$store_id]);
                $store = $stmt->fetch();

                if (!$store) {
                    $error = '门店不存在！';
                } else {
                    // 检查门店是否有关联员工、设备等
                    $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM emp_info WHERE store_id = ?");
                    $stmt->execute([$store_id]);
                    $employees = $stmt->fetch();

                    $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM equip_info WHERE store_id = ?");
                    $stmt->execute([$store_id]);
                    $equipment = $stmt->fetch();

                    if ($employees['count'] > 0 || $equipment['count'] > 0) {
                        $error = '该门店存在关联员工或设备，无法删除！请先转移或删除关联项。';
                    } else {
                        // 删除门店
                        $stmt = $pdo->prepare("DELETE FROM store_info WHERE id = ?");
                        $result = $stmt->execute([$store_id]);

                        if ($result) {
                            record_log("删除门店：{$store['store_name']}");
                            $success = '门店删除成功！';
                        } else {
                            $error = '门店删除失败！';
                        }
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 获取所有门店
try {
    $stmt = $pdo->query("SELECT * FROM store_info ORDER BY id DESC");
    $stores = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取门店列表失败：' . $e->getMessage();
    $stores = [];
}

// 判断是否显示表单
$show_form = false;
$edit_store = null;

// 编辑门店时显示表单并获取门店信息
if (isset($_GET['action']) && $_GET['action'] == 'edit' && isset($_GET['id'])) {
    $show_form = true;
    $edit_id = intval($_GET['id']);
    try {
        $stmt = $pdo->prepare("SELECT * FROM store_info WHERE id = ?");
        $stmt->execute([$edit_id]);
        $edit_store = $stmt->fetch();
        if (!$edit_store) {
            $error = '门店不存在！';
            $show_form = false;
        }
    } catch (PDOException $e) {
        $error = '获取门店信息失败：' . $e->getMessage();
        $show_form = false;
    }
}

// 添加门店时显示表单
if (isset($_GET['action']) && $_GET['action'] == 'add') {
    $show_form = true;
}

// 页面顶部处理成功消息
if (isset($_GET['success'])) {
    if ($_GET['success'] == 'add') {
        $success = '门店添加成功！';
    } elseif ($_GET['success'] == 'edit') {
        $success = '门店信息更新成功！';
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>多门店管理</h2>
            <div class="breadcrumb">
                <a href="index.php">门店管理</a> &gt; 多门店管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <a href="multi.php?action=add" class="btn btn-add">添加门店</a>
            </div>

            <!-- 添加/编辑门店表单 -->
            <?php if ($show_form): ?>
                <div class="form-container">
                    <h3><?php echo $edit_store ? '编辑门店' : '添加门店'; ?></h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="<?php echo $edit_store ? 'edit' : 'add'; ?>">
                        <?php if ($edit_store): ?>
                            <input type="hidden" name="store_id" value="<?php echo $edit_store['id']; ?>">
                        <?php endif; ?>

                        <div class="form-group">
                            <label for="store_name">门店名称：</label>
                            <input type="text" id="store_name" name="store_name" value="<?php echo $edit_store ? htmlspecialchars($edit_store['store_name']) : ''; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="address">门店地址：</label>
                            <input type="text" id="address" name="address" value="<?php echo $edit_store ? htmlspecialchars($edit_store['address']) : ''; ?>">
                        </div>

                        <div class="form-group">
                            <label for="contact_phone">联系电话：</label>
                            <input type="text" id="contact_phone" name="contact_phone" value="<?php echo $edit_store ? htmlspecialchars($edit_store['contact_phone']) : ''; ?>">
                        </div>

                        <div class="form-group">
                            <label for="business_hours">营业时间：</label>
                            <input type="text" id="business_hours" name="business_hours" value="<?php echo $edit_store ? htmlspecialchars($edit_store['business_hours']) : ''; ?>" placeholder="例如: 07:00-22:00">
                        </div>

                        <div class="form-group">
                            <label for="status">状态：</label>
                            <select id="status" name="status">
                                <option value="1" <?php echo ($edit_store && $edit_store['status'] == 1) ? 'selected' : ''; ?>>营业中</option>
                                <option value="0" <?php echo ($edit_store && $edit_store['status'] == 0) ? 'selected' : ''; ?>>已关闭</option>
                            </select>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">保存</button>
                            <a href="multi.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <!-- 门店列表 -->
            <div class="table-container">
                <h3>门店列表</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>门店名称</th>
                            <th>地址</th>
                            <th>联系电话</th>
                            <th>营业时间</th>
                            <th>状态</th>
                            <th>创建时间</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($stores)): ?>
                            <tr>
                                <td colspan="8" class="text-center">暂无门店数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($stores as $store): ?>
                                <tr>
                                    <td><?php echo $store['id']; ?></td>
                                    <td><?php echo htmlspecialchars($store['store_name']); ?></td>
                                    <td><?php echo htmlspecialchars($store['address'] ?: '-'); ?></td>
                                    <td><?php echo htmlspecialchars($store['contact_phone'] ?: '-'); ?></td>
                                    <td><?php echo htmlspecialchars($store['business_hours'] ?: '-'); ?></td>
                                    <td>
                                        <?php
                                        if ($store['status'] == 1) echo '<span class="status-active">营业中</span>';
                                        else echo '<span class="status-inactive">已关闭</span>';
                                        ?>
                                    </td>
                                    <td><?php echo $store['create_time']; ?></td>
                                    <td>
                                        <a href="multi.php?action=edit&id=<?php echo $store['id']; ?>" class="btn btn-sm btn-edit">编辑</a>
                                        <form method="post" action="" class="inline-form">
                                            <input type="hidden" name="action" value="delete">
                                            <input type="hidden" name="store_id" value="<?php echo $store['id']; ?>">
                                            <button type="submit" class="btn btn-sm btn-danger" onclick="return confirm('确定要删除门店 \'<?php echo htmlspecialchars($store['store_name']); ?>\' 吗？');">删除</button>
                                        </form>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>